@@ -264,7 +264,7 @@ typedef struct {
 #define ACTION_TEACH_LINE 276
 #define ACTION_DEMO 300
 #define ACTION_NEXT 301
-#define ACTION_REPEAT 302
+#define ACTION_ENTER 302
 #define ACTION_JUMP 303
 #define ACTION_MORE 304
 #define ACTION_CHAPTER1 311
@@ -303,7 +303,7 @@ typedef struct {
 #define CALC_DECK (-8)
 #define MORE_DECK (-7)
 #define JUMP_DECK (-6)
-#define REPEAT_DECK (-5)
+#define ENTER_DECK (-5)
 #define NEXT_DECK (-4)
 #define CLEAR_DECIMAL_DECK (-3)
 #define CLEAR_DECK (-2)
