@@ -1,7 +1,7 @@
 /*
  * @(#)AbacusP.h
  *
- * Copyright 1994 - 2018  David A. Bagley, bagleyd AT verizon.net
+ * Copyright 1994 - 2020  David A. Bagley, bagleyd AT verizon.net
  *
  * Abacus demo and neat pointers from
  * Copyright 1991 - 1998  Luis Fernandes, elf AT ee.ryerson.ca
@@ -99,7 +99,7 @@ extern void exposeAbacusDemo(AbacusWidget w);
 extern void clearAbacusDemo(AbacusWidget w);
 extern void toggleDemoAbacusDemo(AbacusWidget w);
 extern void showNextAbacusDemo(AbacusWidget w);
-extern void showRepeatAbacusDemo(AbacusWidget w);
+extern void showEnterAbacusDemo(AbacusWidget w);
 extern void showJumpAbacusDemo(AbacusWidget w);
 extern void showMoreAbacusDemo(AbacusWidget w);
 extern void showChapterAbacusDemo(AbacusWidget w, unsigned int chapt);
@@ -160,6 +160,15 @@ extern AbacusClassRec abacusClassRec;
 #define LINES 4
 #define CHARS 64
 
+#define READ_BOOK	"Hit: `Enter' or `e' to read this book"
+#define NEXT_BOOK	"     `Tab' or `n' to skip to the next book"
+#define READ_CHAPTER	"Hit: `Enter' or `e' to read this chapter"
+#define NEXT_CHAPTER	"     `Tab' or `n' to goto the next chapter"
+#define NEXT_LESSON	"Hit: `Tab' or `n' for the next lesson"
+#define READ_LESSON	"     `Enter' or `e' to repeat lesson"
+#define JUMP_LESSON	"     `j' to jump to next chapter"
+#define QUIT		"     `q' to quit the demo"
+
 #define MAX_SLICES 10
 #define COUNTRY_SIZE 3
 #define STRING_SIZE 256
@@ -412,7 +421,7 @@ extern void getMove(AbacusStack *s,
 extern int madeMoves(AbacusStack *s);
 extern void flushMoves(AbacusStack *s);
 extern int numMoves(AbacusStack *s);
-extern void scanMoves(FILE *fp, AbacusWidget w, int moves);
+extern Boolean scanMoves(FILE *fp, AbacusWidget w, int moves);
 extern void printMoves(FILE *fp, AbacusStack *s);
 extern void clearRails(AbacusWidget w);
 extern void clearDecimalRails(AbacusWidget w);
